import { CommonModule } from '@angular/common';
import { Component, Input } from '@angular/core';
import * as L from 'leaflet';
import { Pin } from '../../model/Pin';
import { PinService } from '../../services/pin/pin.service';
import { EditPinPopupComponent } from '../edit-pin-popup/edit-pin-popup.component';

@Component({
  selector: 'app-pin-marker',
  templateUrl: './pin-marker.component.html',
  imports: [CommonModule, EditPinPopupComponent],
})
export class PinMarkerComponent {
  @Input() pin!: Pin;
  @Input() marker!: L.Marker;

  currentIndex: number = 0;

  constructor(private pinService: PinService) {}

  onClosePopup() {
    this.marker.closePopup();
  }

  imageLoaded = false;

  onImageLoad() {
    this.imageLoaded = true;
  }

  onDelete() {
    this.pinService.deletePin(this.pin.id).subscribe(() => {
      this.marker.remove();
    });
  }

  get formattedDescription(): string {
    return this.formatDescription(this.pin.description);
  }

  formatDescription(description: string): string {
    const regex = /@(\w+(-\w+)*(\.\w+(-\w+)*)*)/g;
    return description.replace(
      regex,
      `<a href="/profile/$1" class="text-blue-500 hover:underline">@$1</a>`
    );
  }

  prevSlide(): void {
    this.currentIndex =
      (this.currentIndex - 1 + this.pin.files.length) % this.pin.files.length;
  }

  nextSlide(): void {
    this.currentIndex = (this.currentIndex + 1) % this.pin.files.length;
  }
}
